@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 ctca2_to_ctn = {   'AF': 'Africa',
     'AN': 'Antarctica',
     'AS': 'Asia',
@@ -123,6 +125,7 @@ ccn_to_cca2 = {   '004': 'AF',
     '372': 'IE',
     '376': 'IL',
     '380': 'IT',
+    '383': 'XK',
     '384': 'CI',
     '388': 'JM',
     '392': 'JP',
@@ -165,8 +168,10 @@ ccn_to_cca2 = {   '004': 'AF',
     '520': 'NR',
     '524': 'NP',
     '528': 'NL',
-    '530': 'AN',
+    '531': 'CW',
     '533': 'AW',
+    '534': 'SX',
+    '535': 'BQ',
     '540': 'NC',
     '548': 'VU',
     '554': 'NZ',
@@ -221,8 +226,9 @@ ccn_to_cca2 = {   '004': 'AF',
     '710': 'ZA',
     '716': 'ZW',
     '724': 'ES',
+    '728': 'SS',
+    '729': 'SD',
     '732': 'EH',
-    '736': 'SD',
     '740': 'SR',
     '744': 'SJ',
     '748': 'SZ',
@@ -259,7 +265,8 @@ ccn_to_cca2 = {   '004': 'AF',
     '876': 'WF',
     '882': 'WS',
     '887': 'YE',
-    '894': 'ZM'}
+    '894': 'ZM',
+    'null': 'XX'}
 
 ccn_to_cca3 = {   '004': 'AFG',
     '008': 'ALB',
@@ -370,6 +377,7 @@ ccn_to_cca3 = {   '004': 'AFG',
     '372': 'IRL',
     '376': 'ISR',
     '380': 'ITA',
+    '383': 'XKX',
     '384': 'CIV',
     '388': 'JAM',
     '392': 'JPN',
@@ -412,8 +420,10 @@ ccn_to_cca3 = {   '004': 'AFG',
     '520': 'NRU',
     '524': 'NPL',
     '528': 'NLD',
-    '530': 'ANT',
+    '531': 'CUW',
     '533': 'ABW',
+    '534': 'SXM',
+    '535': 'BES',
     '540': 'NCL',
     '548': 'VUT',
     '554': 'NZL',
@@ -468,8 +478,9 @@ ccn_to_cca3 = {   '004': 'AFG',
     '710': 'ZAF',
     '716': 'ZWE',
     '724': 'ESP',
+    '728': 'SSD',
+    '729': 'SDN',
     '732': 'ESH',
-    '736': 'SDN',
     '740': 'SUR',
     '744': 'SJM',
     '748': 'SWZ',
@@ -506,7 +517,8 @@ ccn_to_cca3 = {   '004': 'AFG',
     '876': 'WLF',
     '882': 'WSM',
     '887': 'YEM',
-    '894': 'ZMB'}
+    '894': 'ZMB',
+    'null': 'null'}
 
 ccn_to_cn = {   '004': 'Afghanistan',
     '008': 'Albania',
@@ -534,10 +546,10 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '074': 'Bouvet Island (Bouvetoya)',
     '076': 'Brazil',
     '084': 'Belize',
-    '086': 'British Indian Ocean Territory (Chagos Archipelago)',
+    '086': 'British Indian Ocean Territory',
     '090': 'Solomon Islands',
     '092': 'British Virgin Islands',
-    '096': 'Brunei Darussalam',
+    '096': 'Brunei',
     '100': 'Bulgaria',
     '104': 'Myanmar',
     '108': 'Burundi',
@@ -590,7 +602,7 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '266': 'Gabon',
     '268': 'Georgia',
     '270': 'Gambia',
-    '275': 'Palestinian Territory',
+    '275': 'Palestine',
     '276': 'Germany',
     '288': 'Ghana',
     '292': 'Gibraltar',
@@ -617,7 +629,8 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '372': 'Ireland',
     '376': 'Israel',
     '380': 'Italy',
-    '384': "Cote d'Ivoire",
+    '383': 'Kosovo',
+    '384': "C\xc3\xb4te d'Ivoire",
     '388': 'Jamaica',
     '392': 'Japan',
     '398': 'Kazakhstan',
@@ -632,7 +645,7 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '426': 'Lesotho',
     '428': 'Latvia',
     '430': 'Liberia',
-    '434': 'Libyan Arab Jamahiriya',
+    '434': 'Libya',
     '438': 'Liechtenstein',
     '440': 'Lithuania',
     '442': 'Luxembourg',
@@ -659,8 +672,10 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '520': 'Nauru',
     '524': 'Nepal',
     '528': 'Netherlands',
-    '530': 'Netherlands Antilles',
+    '531': 'Cura\xc3\xa7ao',
     '533': 'Aruba',
+    '534': 'Sint Maarten (Netherlands)',
+    '535': 'Bonaire',
     '540': 'New Caledonia',
     '548': 'Vanuatu',
     '554': 'New Zealand',
@@ -701,7 +716,7 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '666': 'Saint Pierre and Miquelon',
     '670': 'Saint Vincent and the Grenadines',
     '674': 'San Marino',
-    '678': 'Sao Tome and Principe',
+    '678': 'S\xc3\xa3o Tom\xc3\xa9 and Pr\xc3\xadncipe',
     '682': 'Saudi Arabia',
     '686': 'Senegal',
     '688': 'Serbia',
@@ -715,11 +730,12 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '710': 'South Africa',
     '716': 'Zimbabwe',
     '724': 'Spain',
-    '732': 'Western Sahara',
-    '736': 'Sudan',
+    '728': 'South Sudan',
+    '729': 'Sudan',
+    '732': 'Sahrawi Arab Democratic Republic',
     '740': 'Suriname',
     '744': 'Svalbard & Jan Mayen Islands',
-    '748': 'Swaziland',
+    '748': 'Eswatini',
     '752': 'Sweden',
     '756': 'Switzerland',
     '760': 'Syrian Arab Republic',
@@ -737,7 +753,7 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '798': 'Tuvalu',
     '800': 'Uganda',
     '804': 'Ukraine',
-    '807': 'Macedonia',
+    '807': 'North Macedonia',
     '818': 'Egypt',
     '826': 'United Kingdom of Great Britain & Northern Ireland',
     '831': 'Guernsey',
@@ -753,7 +769,8 @@ ccn_to_cn = {   '004': 'Afghanistan',
     '876': 'Wallis and Futuna',
     '882': 'Samoa',
     '887': 'Yemen',
-    '894': 'Zambia'}
+    '894': 'Zambia',
+    'null': 'Disputed Territory'}
 
 ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '008': 'Republic of Albania',
@@ -775,16 +792,16 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '056': 'Kingdom of Belgium',
     '060': 'Bermuda',
     '064': 'Kingdom of Bhutan',
-    '068': 'Republic of Bolivia',
+    '068': 'Plurinational State of Bolivia',
     '070': 'Bosnia and Herzegovina',
     '072': 'Republic of Botswana',
     '074': 'Bouvet Island (Bouvetoya)',
     '076': 'Federative Republic of Brazil',
     '084': 'Belize',
-    '086': 'British Indian Ocean Territory (Chagos Archipelago)',
+    '086': 'British Indian Ocean Territory',
     '090': 'Solomon Islands',
     '092': 'British Virgin Islands',
-    '096': 'Brunei Darussalam',
+    '096': 'Nation of, the Abode of Peace Brunei',
     '100': 'Republic of Bulgaria',
     '104': 'Union of Myanmar',
     '108': 'Republic of Burundi',
@@ -804,7 +821,7 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '166': 'Cocos (Keeling) Islands',
     '170': 'Republic of Colombia',
     '174': 'Union of the Comoros',
-    '175': 'Mayotte',
+    '175': 'Department of Mayotte',
     '178': 'Republic of the Congo',
     '180': 'Democratic Republic of the Congo',
     '184': 'Cook Islands',
@@ -826,7 +843,7 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '234': 'Faroe Islands',
     '238': 'Falkland Islands (Malvinas)',
     '239': 'South Georgia and the South Sandwich Islands',
-    '242': 'Republic of the Fiji Islands Fiji',
+    '242': 'Republic of Fiji',
     '246': 'Republic of Finland',
     '248': '\xc3\x85land Islands',
     '250': 'French Republic France',
@@ -837,7 +854,7 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '266': 'Gabonese Republic Gabon',
     '268': 'Georgia',
     '270': 'Republic of the Gambia',
-    '275': 'Occupied Palestinian Territory',
+    '275': 'State of Palestine',
     '276': 'Federal Republic of Germany',
     '288': 'Republic of Ghana',
     '292': 'Gibraltar',
@@ -864,7 +881,8 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '372': 'Ireland',
     '376': 'State of Israel',
     '380': 'Italian Republic Italy',
-    '384': "Republic of Cote d'Ivoire",
+    '383': 'Republic of Kosovo',
+    '384': "Republic of C\xc3\xb4te d'Ivoire",
     '388': 'Jamaica',
     '392': 'Japan',
     '398': 'Republic of Kazakhstan',
@@ -879,7 +897,7 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '426': 'Kingdom of Lesotho',
     '428': 'Republic of Latvia',
     '430': 'Republic of Liberia',
-    '434': 'Libyan Arab Jamahiriya',
+    '434': 'State of Libya',
     '438': 'Principality of Liechtenstein',
     '440': 'Republic of Lithuania',
     '442': 'Grand Duchy of Luxembourg',
@@ -897,17 +915,19 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '492': 'Principality of Monaco',
     '496': 'Mongolia',
     '498': 'Republic of Moldova',
-    '499': 'Republic of Montenegro',
+    '499': 'Montenegro',
     '500': 'Montserrat',
     '504': 'Kingdom of Morocco',
     '508': 'Republic of Mozambique',
     '512': 'Sultanate of Oman',
     '516': 'Republic of Namibia',
     '520': 'Republic of Nauru',
-    '524': 'State of Nepal',
+    '524': 'Federal Democratic Republic of Nepal',
     '528': 'Kingdom of the Netherlands',
-    '530': 'Netherlands Antilles',
+    '531': 'Cura\xc3\xa7ao',
     '533': 'Aruba',
+    '534': 'Sint Maarten (Netherlands)',
+    '535': 'Sint Eustatius and Saba Bonaire',
     '540': 'New Caledonia',
     '548': 'Republic of Vanuatu',
     '554': 'New Zealand',
@@ -948,7 +968,7 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '666': 'Saint Pierre and Miquelon',
     '670': 'Saint Vincent and the Grenadines',
     '674': 'Republic of San Marino',
-    '678': 'Democratic Republic of Sao Tome and Principe',
+    '678': 'Democratic Republic of S\xc3\xa3o Tom\xc3\xa9 and Pr\xc3\xadncipe',
     '682': 'Kingdom of Saudi Arabia',
     '686': 'Republic of Senegal',
     '688': 'Republic of Serbia',
@@ -958,15 +978,16 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '703': 'Slovakia (Slovak Republic)',
     '704': 'Socialist Republic of Vietnam',
     '705': 'Republic of Slovenia',
-    '706': 'Somali Republic Somalia',
+    '706': 'Federal Republic of Somalia',
     '710': 'Republic of South Africa',
     '716': 'Republic of Zimbabwe',
     '724': 'Kingdom of Spain',
-    '732': 'Western Sahara',
-    '736': 'Republic of Sudan',
+    '728': 'Republic of South Sudan',
+    '729': 'Republic of the Sudan',
+    '732': 'Sahrawi Arab Democratic Republic',
     '740': 'Republic of Suriname',
     '744': 'Svalbard & Jan Mayen Islands',
-    '748': 'Kingdom of Swaziland',
+    '748': 'Kingdom of Eswatini',
     '752': 'Kingdom of Sweden',
     '756': 'Swiss Confederation Switzerland',
     '760': 'Syrian Arab Republic',
@@ -977,14 +998,14 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '776': 'Kingdom of Tonga',
     '780': 'Republic of Trinidad and Tobago',
     '784': 'United Arab Emirates',
-    '788': 'Tunisian Republic Tunisia',
+    '788': 'Republic of Tunisia',
     '792': 'Republic of Turkey',
     '795': 'Turkmenistan',
     '796': 'Turks and Caicos Islands',
     '798': 'Tuvalu',
     '800': 'Republic of Uganda',
     '804': 'Ukraine',
-    '807': 'the former Yugoslav Republic of Macedonia',
+    '807': 'Republic of North Macedonia',
     '818': 'Arab Republic of Egypt',
     '826': 'United Kingdom of Great Britain & Northern Ireland',
     '831': 'Bailiwick of Guernsey',
@@ -994,13 +1015,14 @@ ccn_to_con = {   '004': 'Islamic Republic of Afghanistan',
     '840': 'United States of America',
     '850': 'United States Virgin Islands',
     '854': 'Burkina Faso',
-    '858': 'Eastern Republic of Uruguay',
+    '858': 'Oriental Republic of Uruguay',
     '860': 'Republic of Uzbekistan',
     '862': 'Bolivarian Republic of Venezuela',
     '876': 'Wallis and Futuna',
     '882': 'Independent State of Samoa',
     '887': 'Yemen',
-    '894': 'Republic of Zambia'}
+    '894': 'Republic of Zambia',
+    'null': 'Disputed Territory'}
 
 cn_to_ccn = {   'Afghanistan': '004',
     'Albania': '008',
@@ -1028,13 +1050,14 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Bermuda': '060',
     'Bhutan': '064',
     'Bolivia': '068',
+    'Bonaire': '535',
     'Bosnia and Herzegovina': '070',
     'Botswana': '072',
     'Bouvet Island (Bouvetoya)': '074',
     'Brazil': '076',
-    'British Indian Ocean Territory (Chagos Archipelago)': '086',
+    'British Indian Ocean Territory': '086',
     'British Virgin Islands': '092',
-    'Brunei Darussalam': '096',
+    'Brunei': '096',
     'Bulgaria': '100',
     'Burkina Faso': '854',
     'Burundi': '108',
@@ -1051,15 +1074,17 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Cocos (Keeling) Islands': '166',
     'Colombia': '170',
     'Comoros': '174',
-    'Congo': '178',
+    'Congo': '180',
     'Cook Islands': '184',
     'Costa Rica': '188',
-    "Cote d'Ivoire": '384',
     'Croatia': '191',
     'Cuba': '192',
+    'Cura\xc3\xa7ao': '531',
     'Cyprus': '196',
     'Czech Republic': '203',
+    "C\xc3\xb4te d'Ivoire": '384',
     'Denmark': '208',
+    'Disputed Territory': 'null',
     'Djibouti': '262',
     'Dominica': '212',
     'Dominican Republic': '214',
@@ -1069,6 +1094,7 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Equatorial Guinea': '226',
     'Eritrea': '232',
     'Estonia': '233',
+    'Eswatini': '748',
     'Ethiopia': '231',
     'Falkland Islands (Malvinas)': '238',
     'Faroe Islands': '234',
@@ -1117,6 +1143,7 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Kenya': '404',
     'Kiribati': '296',
     'Korea': '410',
+    'Kosovo': '383',
     'Kuwait': '414',
     'Kyrgyz Republic': '417',
     "Lao People's Democratic Republic": '418',
@@ -1124,12 +1151,11 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Lebanon': '422',
     'Lesotho': '426',
     'Liberia': '430',
-    'Libyan Arab Jamahiriya': '434',
+    'Libya': '434',
     'Liechtenstein': '438',
     'Lithuania': '440',
     'Luxembourg': '442',
     'Macao': '446',
-    'Macedonia': '807',
     'Madagascar': '450',
     'Malawi': '454',
     'Malaysia': '458',
@@ -1155,7 +1181,6 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Nauru': '520',
     'Nepal': '524',
     'Netherlands': '528',
-    'Netherlands Antilles': '530',
     'New Caledonia': '540',
     'New Zealand': '554',
     'Nicaragua': '558',
@@ -1163,12 +1188,13 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Nigeria': '566',
     'Niue': '570',
     'Norfolk Island': '574',
+    'North Macedonia': '807',
     'Northern Mariana Islands': '580',
     'Norway': '578',
     'Oman': '512',
     'Pakistan': '586',
     'Palau': '585',
-    'Palestinian Territory': '275',
+    'Palestine': '275',
     'Panama': '591',
     'Papua New Guinea': '598',
     'Paraguay': '600',
@@ -1183,6 +1209,7 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Romania': '642',
     'Russian Federation': '643',
     'Rwanda': '646',
+    'Sahrawi Arab Democratic Republic': '732',
     'Saint Barthelemy': '652',
     'Saint Helena': '654',
     'Saint Kitts and Nevis': '659',
@@ -1192,28 +1219,30 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Saint Vincent and the Grenadines': '670',
     'Samoa': '882',
     'San Marino': '674',
-    'Sao Tome and Principe': '678',
     'Saudi Arabia': '682',
     'Senegal': '686',
     'Serbia': '688',
     'Seychelles': '690',
     'Sierra Leone': '694',
     'Singapore': '702',
+    'Sint Maarten (Netherlands)': '534',
     'Slovakia (Slovak Republic)': '703',
     'Slovenia': '705',
     'Solomon Islands': '090',
     'Somalia': '706',
     'South Africa': '710',
     'South Georgia and the South Sandwich Islands': '239',
+    'South Sudan': '728',
     'Spain': '724',
+    'Spratly Islands': 'null',
     'Sri Lanka': '144',
-    'Sudan': '736',
+    'Sudan': '729',
     'Suriname': '740',
     'Svalbard & Jan Mayen Islands': '744',
-    'Swaziland': '748',
     'Sweden': '752',
     'Switzerland': '756',
     'Syrian Arab Republic': '760',
+    'S\xc3\xa3o Tom\xc3\xa9 and Pr\xc3\xadncipe': '678',
     'Taiwan': '158',
     'Tajikistan': '762',
     'Tanzania': '834',
@@ -1232,6 +1261,7 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Ukraine': '804',
     'United Arab Emirates': '784',
     'United Kingdom of Great Britain & Northern Ireland': '826',
+    'United Nations Neutral Zone': 'null',
     'United States Minor Outlying Islands': '581',
     'United States Virgin Islands': '850',
     'United States of America': '840',
@@ -1241,7 +1271,6 @@ cn_to_ccn = {   'Afghanistan': '004',
     'Venezuela': '862',
     'Vietnam': '704',
     'Wallis and Futuna': '876',
-    'Western Sahara': '732',
     'Yemen': '887',
     'Zambia': '894',
     'Zimbabwe': '716',
@@ -1254,7 +1283,6 @@ cca3_to_ccn = {   'ABW': '533',
     'ALA': '248',
     'ALB': '008',
     'AND': '020',
-    'ANT': '530',
     'ARE': '784',
     'ARG': '032',
     'ARM': '051',
@@ -1268,6 +1296,7 @@ cca3_to_ccn = {   'ABW': '533',
     'BDI': '108',
     'BEL': '056',
     'BEN': '204',
+    'BES': '535',
     'BFA': '854',
     'BGD': '050',
     'BGR': '100',
@@ -1301,6 +1330,7 @@ cca3_to_ccn = {   'ABW': '533',
     'CPV': '132',
     'CRI': '188',
     'CUB': '192',
+    'CUW': '531',
     'CXR': '162',
     'CYM': '136',
     'CYP': '196',
@@ -1438,7 +1468,7 @@ cca3_to_ccn = {   'ABW': '533',
     'RUS': '643',
     'RWA': '646',
     'SAU': '682',
-    'SDN': '736',
+    'SDN': '729',
     'SEN': '686',
     'SGP': '702',
     'SGS': '239',
@@ -1451,12 +1481,14 @@ cca3_to_ccn = {   'ABW': '533',
     'SOM': '706',
     'SPM': '666',
     'SRB': '688',
+    'SSD': '728',
     'STP': '678',
     'SUR': '740',
     'SVK': '703',
     'SVN': '705',
     'SWE': '752',
     'SWZ': '748',
+    'SXM': '534',
     'SYC': '690',
     'SYR': '760',
     'TCA': '796',
@@ -1489,10 +1521,12 @@ cca3_to_ccn = {   'ABW': '533',
     'VUT': '548',
     'WLF': '876',
     'WSM': '882',
+    'XKX': '383',
     'YEM': '887',
     'ZAF': '710',
     'ZMB': '894',
-    'ZWE': '716'}
+    'ZWE': '716',
+    'null': 'null'}
 
 cca2_to_ccn = {   'AD': '020',
     'AE': '784',
@@ -1501,7 +1535,6 @@ cca2_to_ccn = {   'AD': '020',
     'AI': '660',
     'AL': '008',
     'AM': '051',
-    'AN': '530',
     'AO': '024',
     'AQ': '010',
     'AR': '032',
@@ -1524,6 +1557,7 @@ cca2_to_ccn = {   'AD': '020',
     'BM': '060',
     'BN': '096',
     'BO': '068',
+    'BQ': '535',
     'BR': '076',
     'BS': '044',
     'BT': '064',
@@ -1546,6 +1580,7 @@ cca2_to_ccn = {   'AD': '020',
     'CR': '188',
     'CU': '192',
     'CV': '132',
+    'CW': '531',
     'CX': '162',
     'CY': '196',
     'CZ': '203',
@@ -1688,7 +1723,7 @@ cca2_to_ccn = {   'AD': '020',
     'SA': '682',
     'SB': '090',
     'SC': '690',
-    'SD': '736',
+    'SD': '729',
     'SE': '752',
     'SG': '702',
     'SH': '654',
@@ -1700,8 +1735,10 @@ cca2_to_ccn = {   'AD': '020',
     'SN': '686',
     'SO': '706',
     'SR': '740',
+    'SS': '728',
     'ST': '678',
     'SV': '222',
+    'SX': '534',
     'SY': '760',
     'SZ': '748',
     'TC': '796',
@@ -1735,6 +1772,10 @@ cca2_to_ccn = {   'AD': '020',
     'VU': '548',
     'WF': '876',
     'WS': '882',
+    'XD': 'null',
+    'XK': '383',
+    'XS': 'null',
+    'XX': 'null',
     'YE': '887',
     'YT': '175',
     'ZA': '710',
@@ -1749,14 +1790,14 @@ ccn_to_ctca2 = {   '004': 'AS',
     '020': 'EU',
     '024': 'AF',
     '028': 'NA',
-    '031': 'AS',
+    '031': 'EU',
     '032': 'SA',
     '036': 'OC',
     '040': 'EU',
     '044': 'NA',
     '048': 'AS',
     '050': 'AS',
-    '051': 'AS',
+    '051': 'EU',
     '052': 'NA',
     '056': 'EU',
     '060': 'NA',
@@ -1767,7 +1808,7 @@ ccn_to_ctca2 = {   '004': 'AS',
     '074': 'AN',
     '076': 'SA',
     '084': 'NA',
-    '086': 'AS',
+    '086': 'AF',
     '090': 'OC',
     '092': 'NA',
     '096': 'AS',
@@ -1797,7 +1838,7 @@ ccn_to_ctca2 = {   '004': 'AS',
     '188': 'NA',
     '191': 'EU',
     '192': 'NA',
-    '196': 'AS',
+    '196': 'EU',
     '203': 'EU',
     '204': 'AF',
     '208': 'EU',
@@ -1818,10 +1859,10 @@ ccn_to_ctca2 = {   '004': 'AS',
     '250': 'EU',
     '254': 'SA',
     '258': 'OC',
-    '260': 'AN',
+    '260': 'AF',
     '262': 'AF',
     '266': 'AF',
-    '268': 'AS',
+    '268': 'EU',
     '270': 'AF',
     '275': 'AS',
     '276': 'EU',
@@ -1850,10 +1891,11 @@ ccn_to_ctca2 = {   '004': 'AS',
     '372': 'EU',
     '376': 'AS',
     '380': 'EU',
+    '383': 'EU',
     '384': 'AF',
     '388': 'NA',
     '392': 'AS',
-    '398': 'AS',
+    '398': 'EU',
     '400': 'AS',
     '404': 'AF',
     '408': 'AS',
@@ -1892,8 +1934,10 @@ ccn_to_ctca2 = {   '004': 'AS',
     '520': 'OC',
     '524': 'AS',
     '528': 'EU',
-    '530': 'NA',
+    '531': 'NA',
     '533': 'NA',
+    '534': 'NA',
+    '535': 'NA',
     '540': 'OC',
     '548': 'OC',
     '554': 'OC',
@@ -1948,8 +1992,9 @@ ccn_to_ctca2 = {   '004': 'AS',
     '710': 'AF',
     '716': 'AF',
     '724': 'EU',
+    '728': 'AF',
+    '729': 'AF',
     '732': 'AF',
-    '736': 'AF',
     '740': 'SA',
     '744': 'EU',
     '748': 'AF',
@@ -1964,14 +2009,14 @@ ccn_to_ctca2 = {   '004': 'AS',
     '780': 'NA',
     '784': 'AS',
     '788': 'AF',
-    '792': 'AS',
+    '792': 'EU',
     '795': 'AS',
     '796': 'NA',
     '798': 'OC',
     '800': 'AF',
     '804': 'EU',
     '807': 'EU',
-    '818': 'AF',
+    '818': 'AS',
     '826': 'EU',
     '831': 'EU',
     '832': 'EU',
@@ -1986,32 +2031,33 @@ ccn_to_ctca2 = {   '004': 'AS',
     '876': 'OC',
     '882': 'OC',
     '887': 'AS',
-    '894': 'AF'}
+    '894': 'AF',
+    'null': 'OC'}
 
 ctca2_to_ccn = {   'AF': [   '012',
               '024',
-              '204',
               '072',
-              '854',
+              '086',
               '108',
               '120',
               '132',
               '140',
               '148',
               '174',
-              '180',
+              '175',
               '178',
-              '384',
-              '262',
-              '818',
+              '180',
+              '204',
               '226',
-              '232',
               '231',
+              '232',
+              '260',
+              '262',
               '266',
               '270',
               '288',
               '324',
-              '624',
+              '384',
               '404',
               '426',
               '430',
@@ -2021,12 +2067,12 @@ ctca2_to_ccn = {   'AF': [   '012',
               '466',
               '478',
               '480',
-              '175',
               '504',
               '508',
               '516',
               '562',
               '566',
+              '624',
               '638',
               '646',
               '654',
@@ -2036,26 +2082,31 @@ ctca2_to_ccn = {   'AF': [   '012',
               '694',
               '706',
               '710',
-              '736',
+              '716',
+              '728',
+              '729',
+              '732',
               '748',
-              '834',
               '768',
               '788',
               '800',
-              '732',
-              '894',
-              '716'],
-    'AN': ['010', '074', '260', '334', '239'],
+              '818',
+              '834',
+              '854',
+              '894'],
+    'AN': ['010', '074', '239', '334'],
     'AS': [   '004',
-              '051',
               '031',
               '048',
               '050',
+              '051',
               '064',
-              '086',
               '096',
+              '104',
               '116',
+              '144',
               '156',
+              '158',
               '162',
               '166',
               '196',
@@ -2067,8 +2118,8 @@ ctca2_to_ccn = {   'AF': [   '012',
               '368',
               '376',
               '392',
-              '400',
               '398',
+              '400',
               '408',
               '410',
               '414',
@@ -2079,61 +2130,64 @@ ctca2_to_ccn = {   'AF': [   '012',
               '458',
               '462',
               '496',
-              '104',
-              '524',
               '512',
+              '524',
               '586',
               '275',
               '608',
+              '626',
               '634',
+              '643',
               '682',
               '702',
-              '144',
+              '704',
               '760',
-              '158',
               '762',
               '764',
-              '626',
+              '784',
               '792',
               '795',
-              '784',
+              '818',
               '860',
-              '704',
-              '887'],
-    'EU': [   '248',
-              '008',
+              '887',
+              'null',
+              'null'],
+    'EU': [   '008',
               '020',
+              '031',
               '040',
-              '112',
+              '051',
               '056',
               '070',
               '100',
+              '112',
               '191',
+              '196',
               '203',
               '208',
               '233',
               '234',
               '246',
+              '248',
               '250',
+              '268',
               '276',
               '292',
               '300',
-              '831',
               '336',
               '348',
               '352',
               '372',
-              '833',
               '380',
-              '832',
+              '398',
+              '383',
               '428',
               '438',
               '440',
               '442',
-              '807',
               '470',
-              '498',
               '492',
+              '498',
               '499',
               '528',
               '578',
@@ -2149,15 +2203,18 @@ ctca2_to_ccn = {   'AF': [   '012',
               '744',
               '752',
               '756',
+              '792',
               '804',
-              '826'],
-    'NA': [   '660',
-              '028',
-              '533',
+              '807',
+              '826',
+              '831',
+              '832',
+              '833'],
+    'NA': [   '028',
               '044',
               '052',
-              '084',
               '060',
+              '084',
               '092',
               '124',
               '136',
@@ -2176,12 +2233,17 @@ ctca2_to_ccn = {   'AF': [   '012',
               '474',
               '484',
               '500',
-              '530',
+              '531',
+              '533',
+              '534',
+              '535',
               '558',
+              '581',
               '591',
               '630',
               '652',
               '659',
+              '660',
               '662',
               '663',
               '666',
@@ -2192,30 +2254,31 @@ ctca2_to_ccn = {   'AF': [   '012',
               '850'],
     'OC': [   '016',
               '036',
+              '090',
               '184',
               '242',
               '258',
-              '316',
               '296',
-              '584',
-              '583',
+              '316',
               '520',
               '540',
+              '548',
               '554',
               '570',
               '574',
               '580',
+              '581',
+              '583',
+              '584',
               '585',
               '598',
               '612',
-              '882',
-              '090',
               '772',
               '776',
               '798',
-              '581',
-              '548',
-              '876'],
+              '876',
+              '882',
+              'null'],
     'SA': [   '032',
               '068',
               '076',
